@@ -1,5 +1,5 @@
 package Limper::Engine::PSGI;
-$Limper::Engine::PSGI::VERSION = '0.002';
+$Limper::Engine::PSGI::VERSION = '0.003';
 use base 'Limper';
 use 5.10.0;
 use strict;
@@ -19,6 +19,8 @@ sub get_psgi {
     request->{uri}         = $env->{REQUEST_URI};
     request->{version}     = $env->{SERVER_PROTOCOL};
     request->{remote_host} = $env->{REMOTE_HOST};
+    (request->{scheme}, request->{authority}, request->{path}, request->{query}, request->{fragment}) =
+        request->{uri} =~ m|(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*)(?:\?([^#]*))?(?:#(.*))?|;	# from https://metacpan.org/pod/URI
     request->{headers}    = {};
 
     request->{headers}{'content-length'} = $env->{CONTENT_LENGTH} if exists $env->{CONTENT_LENGTH};
@@ -64,7 +66,7 @@ Limper::Engine::PSGI - PSGI engine for Limper
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
